==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-6d.js <==
dispMUA.arDispMUAAllocation["m"] =
{
  "mailer by oracle utl_smtp - used by psu foundation" : [ "psufmailer.png" , "http://www.foundation.pdx.edu/" ] ,
  "messagerie internet de microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "marshallsoft smtp/pop3 email engine" : [ "marshallsoft.png" , "http://www.marshallsoft.com/products.htm" ] ,
  "microsoft internet-e-post/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "microsoft windows live mail" : [ "ms_live.png" , "http://www.microsoft.com/" ] ,
  "microsoft outlook, build 10" : [ "outlook_xp.png" , "http://www.microsoft.com/" ] ,
  "mailform (www.mailform.cz)" : [ "mailform.png" , "http://www.mailform.cz/" ] ,
  "mailer @ standleitungen.de" : [ "standleitungen_de.png" , "http://www.standleitungen.de/" ] ,
  "microsoft-outlook-express" : [ "outlook_express.png" , "http://www.microsoft.com/" ] ,
  "microsoft outlook express" : [ "outlook_express.png" , "http://www.microsoft.com/" ] ,
  "microsoft internet e-mail" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "microsoft exchange server" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "microsoft avondale mailer" : [ "microsoft.png" , "http://www.microsoft.com/" ] ,
  "microsoft office outlook" : [ "outlook_2007.png" , "http://www.microsoft.com/" ] ,
  "microsoft internet mail" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "mail sent with web2life" : [ "web2life.png" , "http://www.web2life.de/" ] ,
  "microsoft windows mail" : [ "ms_mail.png" , "http://www.microsoft.com/" ] ,
  "microsoft-windows-mail" : [ "ms_mail.png" , "http://www.microsoft.com/" ] ,
  "mr/2 internet cruiser" : [ "mr2.png" ] ,
  "messagefocus launcher" : [ "adestra_co_uk.png" , "http://www.adestra.co.uk/" ] ,
  "mailer at germany.ru" : [ "germany_ru.png" , "http://www.germany.ru/" ] ,
  "mozilla thunderbird" : [ "thunderbird.png" , "http://www.mozilla-europe.org/en/products/thunderbird/" ] ,
  "microsoft-entourage" : [ "ms_entourage.png" , "http://www.microsoft.com/" ] ,
  "microplanet-gravity" : [ "microplanet.png" ] ,
  "microplanet gravity" : [ "microplanet.png" ] ,
  "messagingengine.com" : [ "messagingengine.png" ] ,
  "maillist controller" : [ "maillist_controller.png" , "http://www.arclab.com/products/amlc/" ] ,
  "mail (gnu mailutils" : [ "shell-bash.png" ] ,
  "mypersonality.info" : [ "mypersonality.png" , "http://www.mypersonality.info/" ] ,
  "microsoft outlook" : [ "outlook_2007.png" , "http://www.microsoft.com/" ] ,
  "mambo open source" : [ "mambo.png" ] ,
  "mail user's shell" : [ "mush.png" ] ,
  "my own hands[tm]" : [ "cweiske.png" ] ,
  "mh dialog server" : [ "mh_dialog.png" , "http://www.millionhandshakes.com/" ] ,
  "mailsite express" : [ "mailsite_express.png" ] ,
  "mails.at webmail" : [ "mails_at.png" , "http://www.mails.at/" ] ,
  "mailcity service" : [ "lycos.png" ] ,
  "mailchimp mailer" : [ "mailchimp.png" , "http://www.mailchimp.com/" ] ,
  "mail/news client" : [ "thunderbird.png" , "http://www.mozilla-europe.org/en/products/thunderbird/" ] ,
  "macintosh eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "mynet webmailer" : [ "mynet.png" ] ,
  "mark/space mail" : [ "markspacemail.png" ] ,
  "mapsolute map24" : [ "map24.png" ] ,
  "mt-newswatcher" : [ "mt_newswatcher.png" ] ,
  "mmd eci mailer" : [ "ieci.png" , "http://www.ieci.es/" ] ,
  "mithi-web-mail" : [ "mithi-web-mail.png" , "http://www.mithi.com/" ] ,
  "message editor" : [ "messageeditor.png" ] ,
  "mailreader.com" : [ "mailreader.png" ] ,
  "mpop web-mail" : [ "mail_ru.png" , "http://www.mail.ru/" ] ,
  "mobile office" : [ "telenor.png" , "http://www.telenor.com/" ] ,
  "microsoft cdo" : [ "ms_cdo.png" , "http://www.microsoft.com/" ] ,
  "messenger-pro" : [ "messenger_pro.png" ] ,
  "maillist king" : [ "maillist_king.png" ] ,
  "mach 5 mailer" : [ "m5_mailer.png" , "http://www.mach5.com/products/mailer/" ] ,
  "minerva mail" : [ "minervamail.png" ] ,
  "match mailer" : [ "match_com.png" , "http://www.match.com/" ] ,
  "mail::mailer" : [ "perl.png" ] ,
  "mach5 mailer" : [ "m5_mailer.png" , "http://www.mach5.com/products/mailer/" ] ,
  "m5mailer.com" : [ "m5_mailer.png" , "http://www.mach5.com/products/mailer/" ] ,
  "mybb mailer" : [ "mybb_mailer.png" , "http://mybb.ru/" ] ,
  "mondo media" : [ "mondo-media.png" , "http://www.mondo-media.de/" ] ,
  "mew version" : [ "mew.png" ] ,
  "memotoo.com" : [ "memotoo.png" , "http://www.memotoo.com/" ] ,
  "melin email" : [ "melin_email.png" , "http://www.melin.eu/" ] ,
  "mediag3.com" : [ "mediag3_com.png" , "http://www.mediag3.com/" ] ,
  "measuremail" : [ "measuremail.png" ] ,
  "mailsender " : [ "mailsender.png" , "http://www.mailsender.com.br/" ] ,
  "mailingwork" : [ "disallow.png" ] ,
  "mailenstein" : [ "mailenstein_de.png" , "http://www.mailenstein.de/" ] ,
  "mintersoft" : [ "mintersoft.png" ] ,
  "mime::lite" : [ "perl.png" ] ,
  "mime-tools" : [ "perl.png" ] ,
  "mercury/32" : [ "mercury.png" ] ,
  "max mailer" : [ "maxbulk.png" ] ,
  "mailprimer" : [ "mailprimer.png" ] ,
  "mailenable" : [ "mailenable.png" , "http://www.mailenable.com/" ] ,
  "maildirect" : [ "maildirect.png" , "http://maildirect.co.in/" ] ,
  "mailanyone" : [ "fusemail.png" ] ,
  "mail::send" : [ "perl.png" ] ,
  "mail.zp.ua" : [ "mail_zp_ua.png" , "http://mail.zp.ua/" ] ,
  "maggi mail" : [ "maggi.png" , "http://www.maggi.de/" ] ,
  "m-acquaint" : [ "m-acquaint.png" , "http://www.macquaint.com/" ] ,
  "mymailout" : [ "mymailout.png" , "http://www.mymailout.com/" ] ,
  "mymail.ch" : [ "mymail_ch.png" , "http://www.mymail.ch/" ] ,
  "mirapoint" : [ "mirapoint.png" ] ,
  "metamail/" : [ "metamail.png" , "http://www.meta.ua/" ] ,
  "messenger" : [ "messenger.png" ] ,
  "mediaworx" : [ "mediaworx.png" , "http://www.mediaworx.com/" ] ,
  "mediawiki" : [ "mediawiki.png" ] ,
  "mediatrix" : [ "mediatrix.png" , "http://www.ityx-solutions.de/" ] ,
  "mallux.de" : [ "mallux_de.png" , "http://www.mallux.de/" ] ,
  "majordomo" : [ "greatcircle.png" ] ,
  "magicmail" : [ "magicmail.png" , "http://magicmail.linuxmagic.com/" ] ,
  "mailsmith" : [ "mailsmith.png" ] ,
  "mail/news" : [ "thunderbird.png" , "http://www.mozilla-europe.org/en/products/thunderbird/" ] ,
  "mulberry" : [ "mulberry.png" ] ,
  "microdot" : [ "microdot.png" ] ,
  "mailroom" : [ "mailroom.png" ] ,
  "mailgate" : [ "mailgate.png" ] ,
  "mail2000" : [ "mail2000.png" , "http://groups.yahoo.com/group/tmail2000/" ] ,
  "mahogany" : [ "mahogany.png" ] ,
  "mesnews" : [ "mesnews.png" ] ,
  "marco -" : [ "marco.png" ] ,
  "manitou" : [ "manitou.png" ] ,
  "mamabuy" : [ "mamabuy.png" , "http://www.mamabuy.de/" ] ,
  "mailout" : [ "mailout.png" ] ,
  "mailman" : [ "mailman.png" , "http://www.list.org/" ] ,
  "mailbee" : [ "mailbee.png" ] ,
  "mail602" : [ "602.png" ] ,
  "mail.bg" : [ "mail_bg.png" , "http://www.mail.bg/" ] ,
  "macsoup" : [ "macsoup.png" ] ,
  "myblog" : [ "myblog.png" , "http://www.myblog.de/" ] ,
  "momail" : [ "momail.png" , "http://www.momail.de/" ] ,
  "modest" : [ "modest.png" , "http://modest.garage.maemo.org/" ] ,
  "marlin" : [ "marlin.png" ] ,
  "mscrm" : [ "ms_crm.png" , "http://www.microsoft.com/crm/" ] ,
  "monit" : [ "monit.png" ] ,
  "mieze" : [ "mieze.png" , "http://www.dietmar-plassmann.de/mieze.html" ] ,
  "magix" : [ "magix.png" , "http://www.magix.com/" ] ,
  "mybb" : [ "mybb.png" , "http://www.mybboard.net/" ] ,
  "mutt" : [ "mutt.png" , "http://www.mutt.org/" ] ,
  "miva" : [ "miva.png" ] ,
  "msn" : [ "msn.png" , "http://www.msn.com/" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-6d.js <==
dispMUA.arDispMUAAllocation["m"] =
{
  "mailer by oracle utl_smtp - used by psu foundation" : [ "psufmailer.png" , "http://www.foundation.pdx.edu/" ] ,
  "messagerie internet de microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "marshallsoft smtp/pop3 email engine" : [ "marshallsoft.png" , "http://www.marshallsoft.com/products.htm" ] ,
  "microsoft internet-e-post/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "microsoft windows live mail" : [ "ms_live.png" , "http://www.microsoft.com/" ] ,
  "microsoft office outlook 12" : [ "ms_outlook12.png" , "http://www.microsoft.com/" ] ,
  "mailform (www.mailform.cz)" : [ "mailform.png" , "http://www.mailform.cz/" ] ,
  "mailer @ standleitungen.de" : [ "standleitungen_de.png" , "http://www.standleitungen.de/" ] ,
  "microsoft-outlook-express" : [ "ms_outlook_express.png" , "http://www.microsoft.com/" ] ,
  "microsoft outlook express" : [ "ms_outlook_express.png" , "http://www.microsoft.com/" ] ,
  "microsoft internet e-mail" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "microsoft exchange server" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "microsoft avondale mailer" : [ "microsoft.png" , "http://www.microsoft.com/" ] ,
  "microsoft office outlook" : [ "ms_outlook.png" , "http://www.microsoft.com/" ] ,
  "microsoft internet mail" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "mail sent with web2life" : [ "web2life.png" , "http://www.web2life.de/" ] ,
  "microsoft windows mail" : [ "ms_mail.png" , "http://www.microsoft.com/" ] ,
  "microsoft-windows-mail" : [ "ms_mail.png" , "http://www.microsoft.com/" ] ,
  "mr/2 internet cruiser" : [ "mr2.png" ] ,
  "messagefocus launcher" : [ "adestra_co_uk.png" , "http://www.adestra.co.uk/" ] ,
  "mailer at germany.ru" : [ "germany_ru.png" , "http://www.germany.ru/" ] ,
  "mozilla thunderbird" : [ "thunderbird.png" , "http://www.mozilla-europe.org/en/products/thunderbird/" ] ,
  "microsoft-entourage" : [ "ms_entourage.png" , "http://www.microsoft.com/" ] ,
  "microplanet-gravity" : [ "microplanet.png" ] ,
  "microplanet gravity" : [ "microplanet.png" ] ,
  "messagingengine.com" : [ "messagingengine.png" ] ,
  "maillist controller" : [ "maillist_controller.png" , "http://www.arclab.com/products/amlc/" ] ,
  "mail (gnu mailutils" : [ "shell-bash.png" ] ,
  "mypersonality.info" : [ "mypersonality.png" , "http://www.mypersonality.info/" ] ,
  "mobildiscounter.de" : [ "mobildiscounter_de.png" , "http://www.mobildiscounter.de/" ] ,
  "microsoft outlook" : [ "ms_outlook.png" , "http://www.microsoft.com/" ] ,
  "mambo open source" : [ "mambo.png" ] ,
  "mail user's shell" : [ "mush.png" ] ,
  "my own hands[tm]" : [ "cweiske.png" ] ,
  "mh dialog server" : [ "mh_dialog.png" , "http://www.millionhandshakes.com/" ] ,
  "mailsite express" : [ "mailsite_express.png" ] ,
  "mails.at webmail" : [ "mails_at.png" , "http://www.mails.at/" ] ,
  "mailed by oracle" : [ "oracle.png" , "http://www.oracle.com/" ] ,
  "mailcity service" : [ "lycos.png" ] ,
  "mailchimp mailer" : [ "mailchimp.png" , "http://www.mailchimp.com/" ] ,
  "mail/news client" : [ "thunderbird.png" , "http://www.mozilla-europe.org/en/products/thunderbird/" ] ,
  "macintosh eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "mynet webmailer" : [ "mynet.png" ] ,
  "mark/space mail" : [ "markspacemail.png" ] ,
  "mapsolute map24" : [ "map24.png" ] ,
  "mt-newswatcher" : [ "mt_newswatcher.png" ] ,
  "mmd eci mailer" : [ "ieci.png" , "http://www.ieci.es/" ] ,
  "mithi-web-mail" : [ "mithi-web-mail.png" , "http://www.mithi.com/" ] ,
  "message editor" : [ "messageeditor.png" ] ,
  "mandic:webmail" : [ "mandic.png" , "http://www.mandic.com.br/" ] ,
  "mailreader.com" : [ "mailreader.png" ] ,
  "mpop web-mail" : [ "mail_ru.png" , "http://www.mail.ru/" ] ,
  "mobile office" : [ "telenor.png" , "http://www.telenor.com/" ] ,
  "microsoft cdo" : [ "ms_cdo.png" , "http://www.microsoft.com/" ] ,
  "messenger-pro" : [ "messenger_pro.png" ] ,
  "maillist king" : [ "maillist_king.png" ] ,
  "mach 5 mailer" : [ "m5_mailer.png" , "http://www.mach5.com/products/mailer/" ] ,
  "minerva mail" : [ "minervamail.png" ] ,
  "match mailer" : [ "match_com.png" , "http://www.match.com/" ] ,
  "mail::mailer" : [ "perl.png" ] ,
  "mach5 mailer" : [ "m5_mailer.png" , "http://www.mach5.com/products/mailer/" ] ,
  "m5mailer.com" : [ "m5_mailer.png" , "http://www.mach5.com/products/mailer/" ] ,
  "mybb mailer" : [ "mybb_mailer.png" , "http://mybb.ru/" ] ,
  "mondo media" : [ "mondo-media.png" , "http://www.mondo-media.de/" ] ,
  "mew version" : [ "mew.png" ] ,
  "memotoo.com" : [ "memotoo.png" , "http://www.memotoo.com/" ] ,
  "melin email" : [ "melin_email.png" , "http://www.melin.eu/" ] ,
  "mediag3.com" : [ "mediag3_com.png" , "http://www.mediag3.com/" ] ,
  "measuremail" : [ "measuremail.png" ] ,
  "mailsender " : [ "mailsender.png" , "http://www.mailsender.com.br/" ] ,
  "mailingwork" : [ "disallow.png" ] ,
  "mailenstein" : [ "mailenstein_de.png" , "http://www.mailenstein.de/" ] ,
  "mintersoft" : [ "mintersoft.png" ] ,
  "mime::lite" : [ "perl.png" ] ,
  "mime-tools" : [ "perl.png" ] ,
  "mercury/32" : [ "mercury.png" ] ,
  "max mailer" : [ "maxbulk.png" ] ,
  "mailweaver" : [ "mailweaver.png" , "http://www.mailweaver.ch/" ] ,
  "mailprimer" : [ "mailprimer.png" ] ,
  "mailenable" : [ "mailenable.png" , "http://www.mailenable.com/" ] ,
  "maildirect" : [ "maildirect.png" , "http://maildirect.co.in/" ] ,
  "mailanyone" : [ "fusemail.png" ] ,
  "mail::send" : [ "perl.png" ] ,
  "mail.zp.ua" : [ "mail_zp_ua.png" , "http://mail.zp.ua/" ] ,
  "maggi mail" : [ "maggi.png" , "http://www.maggi.de/" ] ,
  "m-acquaint" : [ "m-acquaint.png" , "http://www.macquaint.com/" ] ,
  "mymailout" : [ "mymailout.png" , "http://www.mymailout.com/" ] ,
  "mymail.ch" : [ "mymail_ch.png" , "http://www.mymail.ch/" ] ,
  "mirapoint" : [ "mirapoint.png" ] ,
  "metamail/" : [ "metamail.png" , "http://www.meta.ua/" ] ,
  "messenger" : [ "messenger.png" ] ,
  "mediaworx" : [ "mediaworx.png" , "http://www.mediaworx.com/" ] ,
  "mediawiki" : [ "mediawiki.png" ] ,
  "mediatrix" : [ "mediatrix.png" , "http://www.ityx-solutions.de/" ] ,
  "mallux.de" : [ "mallux_de.png" , "http://www.mallux.de/" ] ,
  "majordomo" : [ "greatcircle.png" ] ,
  "magicmail" : [ "magicmail.png" , "http://magicmail.linuxmagic.com/" ] ,
  "mailsmith" : [ "mailsmith.png" ] ,
  "mail/news" : [ "thunderbird.png" , "http://www.mozilla-europe.org/en/products/thunderbird/" ] ,
  "magnewsg4" : [ "magnews.png" , "http://www.mag-news.it/" ] ,
  "mulberry" : [ "mulberry.png" ] ,
  "moto-ezx" : [ "moto-ezx.png" , "http://www.motorola.com/" ] ,
  "microdot" : [ "microdot.png" ] ,
  "mailroom" : [ "mailroom.png" ] ,
  "mailgate" : [ "mailgate.png" ] ,
  "mailcast" : [ "mailcast.png" , "http://www.atwww.com/page.asp?PartId=9" ] ,
  "mailboot" : [ "mailboot.png" , "http://mboot.pl/" ] ,
  "mail2000" : [ "mail2000.png" , "http://groups.yahoo.com/group/tmail2000/" ] ,
  "mahogany" : [ "mahogany.png" ] ,
  "mesnews" : [ "mesnews.png" ] ,
  "marco -" : [ "marco.png" ] ,
  "manitou" : [ "manitou.png" ] ,
  "mamabuy" : [ "mamabuy.png" , "http://www.mamabuy.de/" ] ,
  "mailout" : [ "mailout.png" ] ,
  "mailman" : [ "mailman.png" , "http://www.list.org/" ] ,
  "mailbee" : [ "mailbee.png" ] ,
  "mail602" : [ "602.png" ] ,
  "mail.bg" : [ "mail_bg.png" , "http://www.mail.bg/" ] ,
  "macsoup" : [ "macsoup.png" ] ,
  "myblog" : [ "myblog.png" , "http://www.myblog.de/" ] ,
  "momail" : [ "momail.png" , "http://www.momail.de/" ] ,
  "modest" : [ "modest.png" , "http://modest.garage.maemo.org/" ] ,
  "marlin" : [ "marlin.png" ] ,
  "mscrm" : [ "ms_crm.png" , "http://www.microsoft.com/crm/" ] ,
  "monit" : [ "monit.png" ] ,
  "mieze" : [ "mieze.png" , "http://www.dietmar-plassmann.de/mieze.html" ] ,
  "magix" : [ "magix.png" , "http://www.magix.com/" ] ,
  "mybb" : [ "mybb.png" , "http://www.mybboard.net/" ] ,
  "mutt" : [ "mutt.png" , "http://www.mutt.org/" ] ,
  "miva" : [ "miva.png" ] ,
  "msn" : [ "msn.png" , "http://www.msn.com/" ] ,
}
